@@ -75,7 +75,7 @@ def output_tests(tests, output=sys.stdout):
 
     for test in tests:
         id_str = test.id()
-        output.write(id_str)
+        output.write(six.text_type(id_str))
         output.write(six.text_type('\n'))
 
 
@@ -139,16 +139,16 @@ def output_summary(successful, tests, tests_delta, time, time_delta, values,
 
 
 def output_stream(stream, output=sys.stdout):
-        _binary_stdout = subunit.make_stream_binary(output)
+    _binary_stdout = subunit.make_stream_binary(output)
+    contents = stream.read(65536)
+    assert type(contents) is bytes, \
+        "Bad stream contents %r" % type(contents)
+    # If there are unflushed bytes in the text wrapper, we need to sync..
+    output.flush()
+    while contents:
+        _binary_stdout.write(contents)
         contents = stream.read(65536)
-        assert type(contents) is bytes, \
-            "Bad stream contents %r" % type(contents)
-        # If there are unflushed bytes in the text wrapper, we need to sync..
-        output.flush()
-        while contents:
-            _binary_stdout.write(contents)
-            contents = stream.read(65536)
-        _binary_stdout.flush()
+    _binary_stdout.flush()
 
 
 class ReturnCodeToSubunit(object):
